.. image:: _static/collab-dex-logo.svg
    :align: right
    :alt: Dex.sg
    :target: https://dex.sg

starfish-py API Documentation
=============================

These docs are API Reference docs.

See also the overall :doc:`Starfish API <starfishapi:index>` documentation.

Contents
--------

.. toctree::
    :maxdepth: 4
    :glob:

    getting_started
    agents
    register_asset_squid
    register_asset_remote_agent
    modules/starfish
    classes/ocean
    classes/account
    classes/agent
    classes/asset
    classes/listing
    classes/purchase
    classes/job
